summaryrefslogtreecommitdiffstats
path: root/kexi/plugins/tables/kexilookupcolumnpage.h
diff options
context:
space:
mode:
Diffstat (limited to 'kexi/plugins/tables/kexilookupcolumnpage.h')
-rw-r--r--kexi/plugins/tables/kexilookupcolumnpage.h21
1 files changed, 11 insertions, 10 deletions
diff --git a/kexi/plugins/tables/kexilookupcolumnpage.h b/kexi/plugins/tables/kexilookupcolumnpage.h
index 457b2e3d..f7b79bb2 100644
--- a/kexi/plugins/tables/kexilookupcolumnpage.h
+++ b/kexi/plugins/tables/kexilookupcolumnpage.h
@@ -19,7 +19,7 @@
#ifndef KEXILOOKUPCOLUMNPAGE_H
#define KEXILOOKUPCOLUMNPAGE_H
-#include <qwidget.h>
+#include <tqwidget.h>
#include <kexidb/field.h>
#include <kexidb/utils.h>
#include <koproperty/set.h>
@@ -31,9 +31,9 @@ class KexiFieldComboBox;
class KexiFieldListView;
class KexiProject;
class KexiSmallToolButton;
-class QToolButton;
-class QLabel;
-class QFrame;
+class TQToolButton;
+class TQLabel;
+class TQFrame;
//! @short A page within table designer's property pane, providing lookup column editor.
/*! It's data model is basically KexiDB::LookupFieldSchema class, but the page does
@@ -42,12 +42,13 @@ class QFrame;
@todo not all features of KexiDB::LookupFieldSchema class are displayed on this page yet
*/
-class KexiLookupColumnPage : public QWidget
+class KexiLookupColumnPage : public TQWidget
{
Q_OBJECT
+ TQ_OBJECT
public:
- KexiLookupColumnPage(QWidget *parent);
+ KexiLookupColumnPage(TQWidget *tqparent);
virtual ~KexiLookupColumnPage();
public slots:
@@ -61,14 +62,14 @@ class KexiLookupColumnPage : public QWidget
signals:
//! Signal emitted when helper button 'Go to selected row sourcesource' is clicked.
- void jumpToObjectRequested(const QCString& mime, const QCString& name);
+ void jumpToObjectRequested(const TQCString& mime, const TQCString& name);
// /*! Signal emitted when current bound column has been changed. */
// void boundColumnChanged(const QString& string, const QString& caption,
// KexiDB::Field::Type type);
protected slots:
- void slotRowSourceTextChanged(const QString & string);
+ void slotRowSourceTextChanged(const TQString & string);
void slotRowSourceChanged();
void slotGotoSelectedRowSource();
void slotBoundColumnSelected();
@@ -78,7 +79,7 @@ class KexiLookupColumnPage : public QWidget
void updateBoundColumnWidgetsAvailability();
//! Used instead of m_propertySet->changeProperty() to honor m_propertySetEnabled
- void changeProperty(const QCString &property, const QVariant &value);
+ void changeProperty(const TQCString &property, const TQVariant &value);
private:
class Private;
@@ -61,14 +62,14 @@ class KexiLookupColumnPage : public QWidget
// /*! Signal emitted when current bound column has been changed. */
-// void boundColumnChanged(const QString& string, const QString& caption,
+// void boundColumnChanged(const TQString& string, const TQString& caption,
// KexiDB::Field::Type type);
protected slots: